@@ -1,133 +1,133 @@
 BUILD_BIT = '64bit'
 BUILD_CPU = 'ARMv8 (64-bit) Family 8 Model D4C Revision   0, Qualcomm Technologies Inc'
-BUILD_DATE = '2025-01-25'
+BUILD_DATE = '2025-03-16'
 BUILD_MACHINE = 'ARM64'
 BUILD_OS = 'Microsoft Windows 11 Pro'
-BUILD_TIME = '08:25'
+BUILD_TIME = '21:30'
 BUILD_TYPE = ''
-COMPILER_VERSION = 'clang version 19.1.7'
+COMPILER_VERSION = 'clang version 20.1.0'
 CYTHON_VERSION = '3.0.11'
-LINKER_VERSION = 'LLD 19.1.7 (https://github.com/msys2/MINGW-packages 7f825cf74e5ea42e46b2b0a0020b4f781b81defd) (compatible with GNU linkers)'
+LINKER_VERSION = 'LLD 20.1.0 (https://github.com/msys2/MINGW-packages 9b15547180ec534fc1e1e01179f9f4da745e80f8) (compatible with GNU linkers)'
 NVCC_VERSION = ''
-PYTHON_VERSION = '3.12.8'
+PYTHON_VERSION = '3.12.9'
 lib_base = '2022.06-1'
 lib_basedevel = '2024.11-1'
-lib_bash = '5.2.037-1'
+lib_bash = '5.2.037-2'
 lib_bashcompletion = '2.16.0-1'
-lib_binutils = '2.43.1-1'
+lib_binutils = '2.44-1'
 lib_bison = '3.8.2-5'
 lib_brotli = '1.1.0-1'
 lib_bsdtar = '3.7.7-1'
 lib_bzip2 = '1.0.8-4'
-lib_cacertificates = '20240203-2'
+lib_cacertificates = '20241223-1'
 lib_coreutils = '8.32-5'
-lib_curl = '8.11.1-1'
+lib_curl = '8.12.1-1'
 lib_dash = '0.5.12-1'
 lib_db = '6.2.32-5'
 lib_diffstat = '1.67-1'
-lib_diffutils = '3.10-1'
+lib_diffutils = '3.11-1'
 lib_dos2unix = '7.5.2-1'
 lib_etcupdate = '2.3.99-1'
-lib_file = '5.46-1'
-lib_filesystem = '2024.12.18-1'
+lib_file = '5.46-2'
+lib_filesystem = '2025.02.23-1'
 lib_findutils = '4.10.0-2'
-lib_flex = '2.6.4-3'
+lib_flex = '2.6.4-4'
 lib_gawk = '5.3.1-1'
 lib_gcclibs = '13.3.0-1'
 lib_gdbm = '1.24-1'
 lib_getent = '2.18.90-5'
-lib_gettext = '0.22.4-1'
+lib_gettext = '0.22.5-1'
 lib_gmp = '6.3.0-1'
-lib_gnupg = '2.4.7-1'
-lib_grep = '1~3.0-6'
+lib_gnupg = '2.4.7-2'
+lib_grep = '1~3.0-7'
 lib_gzip = '1.13-1'
 lib_heimdallibs = '7.8.0-5'
 lib_inetutils = '2.5-2'
 lib_info = '7.1.1-1'
 lib_less = '668-1'
 lib_libargp = '20241207-1'
-lib_libasprintf = '0.22.4-1'
-lib_libassuan = '2.5.7-1'
+lib_libasprintf = '0.22.5-1'
+lib_libassuan = '3.0.2-1'
 lib_libbz2 = '1.0.8-4'
-lib_libcurl = '8.11.1-1'
+lib_libcurl = '8.12.1-1'
 lib_libdb = '6.2.32-5'
 lib_libedit = '20240808_3.1-1'
-lib_libexpat = '2.6.4-1'
-lib_libffi = '3.4.6-1'
+lib_libexpat = '2.7.0-1'
+lib_libffi = '3.4.7-1'
 lib_libgcrypt = '1.11.0-1'
 lib_libgdbm = '1.24-1'
-lib_libgettextpo = '0.22.4-1'
-lib_libgnutls = '3.8.8-1'
+lib_libgettextpo = '0.22.5-1'
+lib_libgnutls = '3.8.9-1'
 lib_libgpgerror = '1.51-1'
 lib_libhogweed = '3.10.1-1'
 lib_libiconv = '1.18-1'
-lib_libidn2 = '2.3.7-1'
-lib_libintl = '0.22.4-1'
+lib_libidn2 = '2.3.8-1'
+lib_libintl = '0.22.5-1'
 lib_libksba = '1.6.7-1'
 lib_liblz4 = '1.10.0-1'
 lib_liblzma = '5.6.4-1'
 lib_libnettle = '3.10.1-1'
-lib_libnghttp2 = '1.64.0-1'
+lib_libnghttp2 = '1.65.0-1'
 lib_libnpth = '1.8-1'
-lib_libopenssl = '3.4.0-1'
+lib_libopenssl = '3.4.1-1'
 lib_libp11kit = '0.25.5-2'
-lib_libpcre = '8.45-4'
-lib_libpcre28 = '10.44-1'
+lib_libpcre = '8.45-5'
+lib_libpcre28 = '10.45-1'
 lib_libpsl = '0.21.5-2'
 lib_libreadline = '8.2.013-1'
 lib_libsqlite = '3.46.1-1'
 lib_libssh2 = '1.11.1-1'
-lib_libtasn1 = '4.19.0-1'
-lib_libunistring = '1.2-1'
-lib_libutillinux = '2.35.2-4'
+lib_libtasn1 = '4.20.0-1'
+lib_libunistring = '1.3-1'
+lib_libutillinux = '2.40.2-2'
 lib_libxcrypt = '4.4.38-1'
-lib_libzstd = '1.5.6-1'
+lib_libzstd = '1.5.7-1'
 lib_m4 = '1.4.19-2'
 lib_make = '4.4.1-2'
 lib_mingww64clangaarch64adwaitaicontheme = '47.0-1'
 lib_mingww64clangaarch64adwaitaiconthemelegacy = '46.2-1'
-lib_mingww64clangaarch64atk = '2.54.1-1'
+lib_mingww64clangaarch64atk = '2.56.0-1'
 lib_mingww64clangaarch64brotli = '1.1.0-4'
 lib_mingww64clangaarch64bzip2 = '1.0.8-3'
-lib_mingww64clangaarch64cairo = '1.18.2-2'
-lib_mingww64clangaarch64clang = '19.1.7-1'
-lib_mingww64clangaarch64clanganalyzer = '19.1.7-1'
-lib_mingww64clangaarch64clanglibs = '19.1.7-1'
-lib_mingww64clangaarch64clangtoolsextra = '19.1.7-1'
-lib_mingww64clangaarch64compilerrt = '19.1.7-1'
-lib_mingww64clangaarch64crtgit = '12.0.0.r473.gce0d0bfb7-1'
+lib_mingww64clangaarch64cairo = '1.18.4-1'
+lib_mingww64clangaarch64clang = '20.1.0-1'
+lib_mingww64clangaarch64clanganalyzer = '20.1.0-1'
+lib_mingww64clangaarch64clanglibs = '20.1.0-1'
+lib_mingww64clangaarch64clangtoolsextra = '20.1.0-1'
+lib_mingww64clangaarch64compilerrt = '20.1.0-1'
+lib_mingww64clangaarch64crtgit = '12.0.0.r576.g49111ba98-1'
 lib_mingww64clangaarch64cython = '3.0.11-2'
 lib_mingww64clangaarch64eglheaders = '1.5.r255.9ab6036-1'
-lib_mingww64clangaarch64expat = '2.6.4-1'
+lib_mingww64clangaarch64expat = '2.7.0-1'
 lib_mingww64clangaarch64fontconfig = '2.16.0-1'
 lib_mingww64clangaarch64freetype = '2.13.3-1'
 lib_mingww64clangaarch64fribidi = '1.0.16-1'
 lib_mingww64clangaarch64gdkpixbuf2 = '2.42.12-4'
-lib_mingww64clangaarch64gettextruntime = '0.23.1-1'
+lib_mingww64clangaarch64gettextruntime = '0.24-1'
 lib_mingww64clangaarch64giflib = '5.2.2-1'
 lib_mingww64clangaarch64glesheaders = '3.2.r1005.d127c30-1'
-lib_mingww64clangaarch64glib2 = '2.82.4-1'
-lib_mingww64clangaarch64gobjectintrospectionruntime = '1.82.0-2'
+lib_mingww64clangaarch64glib2 = '2.84.0-1'
+lib_mingww64clangaarch64gobjectintrospectionruntime = '1.84.0-1'
 lib_mingww64clangaarch64graphite2 = '1.3.14-3'
-lib_mingww64clangaarch64gtk3 = '3.24.43-1'
-lib_mingww64clangaarch64gtkupdateiconcache = '3.24.43-1'
-lib_mingww64clangaarch64harfbuzz = '10.2.0-2'
-lib_mingww64clangaarch64headersgit = '12.0.0.r473.gce0d0bfb7-1'
+lib_mingww64clangaarch64gtk3 = '3.24.49-1'
+lib_mingww64clangaarch64gtkupdateiconcache = '3.24.49-1'
+lib_mingww64clangaarch64harfbuzz = '10.4.0-1'
+lib_mingww64clangaarch64headersgit = '12.0.0.r576.g49111ba98-1'
 lib_mingww64clangaarch64hicoloricontheme = '0.18-1'
 lib_mingww64clangaarch64jbigkit = '2.1-5'
 lib_mingww64clangaarch64jsonglib = '1.10.6-1'
-lib_mingww64clangaarch64lcms2 = '2.16-1'
+lib_mingww64clangaarch64lcms2 = '2.17-1'
 lib_mingww64clangaarch64lerc = '4.0.0-1'
-lib_mingww64clangaarch64libc = '19.1.7-1'
+lib_mingww64clangaarch64libc = '20.1.0-1'
 lib_mingww64clangaarch64libdatrie = '0.2.13-3'
 lib_mingww64clangaarch64libdeflate = '1.23-1'
 lib_mingww64clangaarch64libepoxy = '1.5.10-5'
-lib_mingww64clangaarch64libffi = '3.4.6-1'
+lib_mingww64clangaarch64libffi = '3.4.7-1'
 lib_mingww64clangaarch64libiconv = '1.18-1'
-lib_mingww64clangaarch64libimagequant = '4.3.3-2'
+lib_mingww64clangaarch64libimagequant = '4.3.4-3'
 lib_mingww64clangaarch64libjpegturbo = '3.1.0-1'
-lib_mingww64clangaarch64libmanglegit = '12.0.0.r473.gce0d0bfb7-1'
-lib_mingww64clangaarch64libpng = '1.6.45-1'
+lib_mingww64clangaarch64libmanglegit = '12.0.0.r576.g49111ba98-1'
+lib_mingww64clangaarch64libpng = '1.6.47-1'
 lib_mingww64clangaarch64libraqm = '0.10.2-1'
 lib_mingww64clangaarch64librsvg = '2.59.2-3'
 lib_mingww64clangaarch64libspng = '0.7.4-1'
@@ -135,42 +135,42 @@ lib_mingww64clangaarch64libsystre = '1.0.1-6'
 lib_mingww64clangaarch64libthai = '0.1.29-3'
 lib_mingww64clangaarch64libtiff = '4.7.0-1'
 lib_mingww64clangaarch64libtre = '0.9.0-1'
-lib_mingww64clangaarch64libunwind = '19.1.7-1'
+lib_mingww64clangaarch64libunwind = '20.1.0-1'
 lib_mingww64clangaarch64libvpx = '1.15.0-1'
 lib_mingww64clangaarch64libwebp = '1.5.0-1'
-lib_mingww64clangaarch64libwinpthreadgit = '12.0.0.r473.gce0d0bfb7-1'
+lib_mingww64clangaarch64libwinpthreadgit = '12.0.0.r576.g49111ba98-1'
 lib_mingww64clangaarch64libx264 = '0.164.r3161.a354f11-3'
-lib_mingww64clangaarch64libxml2 = '2.12.9-2'
-lib_mingww64clangaarch64libyuv = '1899.r2785.47ddac299-1'
-lib_mingww64clangaarch64lld = '19.1.7-1'
-lib_mingww64clangaarch64lldb = '19.1.7-1'
-lib_mingww64clangaarch64llvm = '19.1.7-1'
-lib_mingww64clangaarch64llvmlibs = '19.1.7-1'
-lib_mingww64clangaarch64llvmopenmp = '19.1.7-1'
+lib_mingww64clangaarch64libxml2 = '2.12.10-1'
+lib_mingww64clangaarch64libyuv = '1905.r2808.61354d267-1'
+lib_mingww64clangaarch64lld = '20.1.0-1'
+lib_mingww64clangaarch64lldb = '20.1.0-1'
+lib_mingww64clangaarch64llvm = '20.1.0-1'
+lib_mingww64clangaarch64llvmlibs = '20.1.0-1'
+lib_mingww64clangaarch64llvmopenmp = '20.1.0-1'
 lib_mingww64clangaarch64lz4 = '1.10.0-1'
 lib_mingww64clangaarch64lzo2 = '2.10-2'
 lib_mingww64clangaarch64make = '4.4.1-3'
 lib_mingww64clangaarch64mpdecimal = '4.0.0-1'
 lib_mingww64clangaarch64ncurses = '6.5.20241228-3'
 lib_mingww64clangaarch64openjpeg2 = '2.5.3-1'
-lib_mingww64clangaarch64openssl = '3.4.0-1'
-lib_mingww64clangaarch64pango = '1.56.1-1'
-lib_mingww64clangaarch64pcre2 = '10.44-2'
+lib_mingww64clangaarch64openssl = '3.4.1-1'
+lib_mingww64clangaarch64pango = '1.56.3-1'
+lib_mingww64clangaarch64pcre2 = '10.45-1'
 lib_mingww64clangaarch64pixman = '0.44.2-1'
 lib_mingww64clangaarch64pkgconf = '1~2.3.0-1'
-lib_mingww64clangaarch64python = '3.12.8-2'
+lib_mingww64clangaarch64python = '3.12.9-3'
 lib_mingww64clangaarch64pythonbuild = '1.2.2.post1-1'
 lib_mingww64clangaarch64pythoncairo = '1.27.0-2'
-lib_mingww64clangaarch64pythoncomtypes = '1.4.9-1'
-lib_mingww64clangaarch64pythongobject = '3.50.0-2'
+lib_mingww64clangaarch64pythoncomtypes = '1.4.10-1'
+lib_mingww64clangaarch64pythongobject = '3.52.3-1'
 lib_mingww64clangaarch64pythoninstaller = '0.7.0-4'
 lib_mingww64clangaarch64pythonpackaging = '24.2-1'
-lib_mingww64clangaarch64pythonpillow = '11.1.0-1'
+lib_mingww64clangaarch64pythonpillow = '11.1.0-5'
 lib_mingww64clangaarch64pythonpyopengl = '3.1.9-1'
 lib_mingww64clangaarch64pythonpyprojecthooks = '1.2.0-1'
 lib_mingww64clangaarch64pythonpyvda = '0.5.0-1'
 lib_mingww64clangaarch64pythonpywin32 = '308-3'
-lib_mingww64clangaarch64pythonsetproctitle = '1.3.4-2'
+lib_mingww64clangaarch64pythonsetproctitle = '1.3.5-1'
 lib_mingww64clangaarch64pythonsetuptools = '75.8.0-1'
 lib_mingww64clangaarch64readline = '8.2.013-1'
 lib_mingww64clangaarch64sharedmimeinfo = '2.4-1'
@@ -178,31 +178,31 @@ lib_mingww64clangaarch64sqlite3 = '3.47.2-1'
 lib_mingww64clangaarch64tcl = '8.6.13-1'
 lib_mingww64clangaarch64termcap = '1.3.1-7'
 lib_mingww64clangaarch64tk = '8.6.13-1'
-lib_mingww64clangaarch64toolsgit = '12.0.0.r473.gce0d0bfb7-1'
+lib_mingww64clangaarch64toolsgit = '12.0.0.r576.g49111ba98-1'
 lib_mingww64clangaarch64tzdata = '2025a-1'
 lib_mingww64clangaarch64wineditline = '2.208-1'
-lib_mingww64clangaarch64winpthreadsgit = '12.0.0.r473.gce0d0bfb7-1'
-lib_mingww64clangaarch64winstorecompatgit = '12.0.0.r473.gce0d0bfb7-1'
+lib_mingww64clangaarch64winpthreadsgit = '12.0.0.r576.g49111ba98-1'
+lib_mingww64clangaarch64winstorecompatgit = '12.0.0.r576.g49111ba98-1'
 lib_mingww64clangaarch64xxhash = '0.8.3-1'
 lib_mingww64clangaarch64xz = '5.6.4-1'
 lib_mingww64clangaarch64zlib = '1.3.1-1'
-lib_mingww64clangaarch64zstd = '1.5.6-2'
-lib_mintty = '1~3.7.7-1'
+lib_mingww64clangaarch64zstd = '1.5.7-1'
+lib_mintty = '1~3.7.7-2'
 lib_mpfr = '4.2.1-1'
-lib_msys2keyring = '1~20241007-1'
+lib_msys2keyring = '1~20250214-1'
 lib_msys2launcher = '1.5-3'
-lib_msys2runtime = '3.5.5-3'
-lib_nano = '8.2-1'
+lib_msys2runtime = '3.5.7-4'
+lib_nano = '8.3-1'
 lib_ncurses = '6.5.20240831-2'
 lib_nettle = '3.10.1-1'
-lib_openssl = '3.4.0-1'
+lib_openssl = '3.4.1-1'
 lib_p11kit = '0.25.5-2'
-lib_pacman = '6.1.0-10'
+lib_pacman = '6.1.0-11'
 lib_pacmancontrib = '1.10.6-1'
-lib_pacmanmirrors = '20241217-1'
-lib_patch = '2.7.6-2'
-lib_perl = '5.38.2-2'
-lib_pinentry = '1.3.1-1'
+lib_pacmanmirrors = '20250220-1'
+lib_patch = '2.7.6-3'
+lib_perl = '5.38.2-3'
+lib_pinentry = '1.3.1-2'
 lib_procpsng = '4.0.5-1'
 lib_psmisc = '23.7-1'
 lib_rebase = '4.5.0-4'
@@ -212,10 +212,10 @@ lib_texinfo = '7.1.1-1'
 lib_texinfotex = '7.1.1-1'
 lib_time = '1.9-3'
 lib_tzcode = '2025a-1'
-lib_utillinux = '2.35.2-4'
-lib_vim = '9.1.1006-1'
+lib_utillinux = '2.40.2-2'
+lib_vim = '9.1.1006-2'
 lib_wget = '1.25.0-1'
 lib_which = '2.21-4'
 lib_xz = '5.6.4-1'
 lib_zlib = '1.3.1-1'
-lib_zstd = '1.5.6-1'
+lib_zstd = '1.5.7-1'
